slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSKrylovSchurGetSubcommMats

Gets the eigenproblem matrices stored internally in the subcommunicator to which the calling process belongs.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSKrylovSchurGetSubcommMats(EPS eps,Mat *A,Mat *B)

Collective on the subcommunicator

### Input Parameter

| eps | - the eigenproblem solver context

### Output Parameters

| A | - the matrix associated with the eigensystem
| B | - the second matrix in the case of generalized eigenproblems

### Notes

This is the analog of EPSGetOperators(), but returns the matrices distributed differently (in the subcommunicator rather than in the parent communicator).

These matrices should not be modified by the user.

### See Also

EPSSetInterval(), EPSKrylovSchurSetPartitions(), EPSKrylovSchurGetSubcommInfo()

### Level

advanced

### Location

src/eps/impls/krylov/krylovschur/krylovschur.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages